vfbLib.ufo.builder.VfbToUfoBuilder
==================================

.. currentmodule:: vfbLib.ufo.builder

.. autoclass:: VfbToUfoBuilder
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~VfbToUfoBuilder.__init__
      ~VfbToUfoBuilder.add_axis_mappings
      ~VfbToUfoBuilder.add_ot_class
      ~VfbToUfoBuilder.assure_tt_glyphlib
      ~VfbToUfoBuilder.assure_tt_lib
      ~VfbToUfoBuilder.build
      ~VfbToUfoBuilder.build_mm_glyph
      ~VfbToUfoBuilder.build_tt_glyph_lib
      ~VfbToUfoBuilder.build_tt_stems_lib
      ~VfbToUfoBuilder.build_tt_zones_lib
      ~VfbToUfoBuilder.get_designspace
      ~VfbToUfoBuilder.get_master_info
      ~VfbToUfoBuilder.get_master_path
      ~VfbToUfoBuilder.get_ufo_master
      ~VfbToUfoBuilder.get_ufo_masters
      ~VfbToUfoBuilder.get_ufos_designspace
      ~VfbToUfoBuilder.set_feature_code
      ~VfbToUfoBuilder.set_glyph_background
      ~VfbToUfoBuilder.set_tt_code_stop
      ~VfbToUfoBuilder.set_tt_pixel_snap
      ~VfbToUfoBuilder.set_tt_stem_ppms
      ~VfbToUfoBuilder.set_tt_stem_ppms_1
      ~VfbToUfoBuilder.set_tt_stems
      ~VfbToUfoBuilder.set_tt_zone_deltas
      ~VfbToUfoBuilder.set_tt_zone_stop
      ~VfbToUfoBuilder.set_tt_zones
      ~VfbToUfoBuilder.write
   
   

   
   
   